:orphan:

.. _contribute:

Contribute
##########

We are always looking for contributors, and want to grow the developer base for
Bokeh. The `Discourse`_ is the best place to get in touch with core developers,
and the :ref:`devguide` is a great place to get set up for working on Bokeh. We
are eager to assist and mentor new contributors.

* *If you are a developer proficient in R, Julia, Swift, or other languages,
  you can help make Bokeh available to entire new audiences.*

..

* *If you are a JavaScript developer, you can help make Bokeh easier to use
  directly from JavaScript.*

..

* *If you are a designer, you can help improve the look of Bokeh plots and
  documentation.*

..

* *If you are a user and have built something awesome with Bokeh you can add
  it to our showcase.*

Specific areas we could use help and expertise with:

* Support for mobile and touch platforms
* Maintenance of RBokeh and other language bindings
* Windows support and testing
* Visual design and styling
* WebGL performance optimization

Of course, we can also use monetary contributions to help with costs associated
with running the project. If you would like to contribute financially to Bokeh,
please make a `donation through NumFOCUS`_.

.. _Discourse: https://discourse.bokeh.org
.. _donation through NumFOCUS: https://numfocus.salsalabs.org/donate-to-bokeh/index.html
